==> syntool_metadata-1.0.168.tar.gz: syntool_metadata-1.0.168/syntool_metadata/__init__.py <==
# -*- coding: utf-8 -*-
# vim: ts=4:sts=4:sw=4
#
# Copyright (C) 2016-2021 OceanDataLab
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


__description__ = ('Handle metadata retrieval and update in Syntool')
__version__ = '1.0'
__author__ = ('Sylvain Herlédan <sylvain.herledan@oceandatalab.com>, '
              'Ziad El Khoury Hanna <ziad.khoury.hanna@oceandatalab.com>')
__author_email__ = 'syntool@oceandatalab.com'
__url__ = 'https://git.oceandatalab.com/syntool_odl/syntool_metadata'
__keywords__ = ()
__classifiers__ = ('Environment :: Console',
                   'Natural Language :: English',
                   'Programming Language :: Python :: 2',
                   'Programming Language :: Python :: 2.7',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.6',
                   'Programming Language :: Python :: Implementation :: '
                   'CPython',
                   'Development Status :: 1 - Alpha',)

==> syntool_metadata-1.0.189.tar.gz: syntool_metadata-1.0.189/syntool_metadata/__init__.py <==
# -*- coding: utf-8 -*-
# vim: ts=4:sts=4:sw=4
#
# Copyright (C) 2016-2024 OceanDataLab
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


__description__ = ('Handle metadata retrieval and update in Syntool')
__version__ = '1.0'
__author__ = ('Sylvain Herlédan <sylvain.herledan@oceandatalab.com>, '
              'Ziad El Khoury Hanna <ziad.khoury.hanna@oceandatalab.com>')
__author_email__ = 'syntool@oceandatalab.com'
__url__ = 'https://git.oceandatalab.com/syntool_odl/syntool_metadata'
__keywords__ = []
__classifiers__ = ['Environment :: Console',
                   'Natural Language :: English',
                   'Programming Language :: Python :: 2',
                   'Programming Language :: Python :: 2.7',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.6',
                   'Programming Language :: Python :: Implementation :: '
                   'CPython',
                   'Development Status :: 1 - Alpha',]
